@@ -1,6 +1,10 @@
+import sys
 from typing import Mapping
 
-import importlib_metadata
+if sys.version_info[:2] >= (3, 8):  # pragma: no cover
+    import importlib.metadata as importlib_metadata
+else:  # pragma: no cover
+    import importlib_metadata
 
 
 def extract_metadata() -> Mapping[str, str]:
